@@ -1,7 +1,8 @@
 use std::cmp::max;
 
+use crate::time::{Clock, Utc};
 use borsh::{BorshDeserialize, BorshSerialize};
-use chrono::{DateTime, Utc};
+use chrono::DateTime;
 use near_crypto::Signature;
 use num_rational::Rational;
 use primitive_types::U256;
@@ -240,8 +241,7 @@ impl Block {
         );
 
         let new_total_supply = prev.total_supply() + minted_amount.unwrap_or(0) - balance_burnt;
-
-        let now = to_timestamp(Utc::now());
+        let now = to_timestamp(Clock::utc());
         let time = if now <= prev.raw_timestamp() { prev.raw_timestamp() + 1 } else { now };
 
         let (vrf_value, vrf_proof) = signer.compute_vrf_with_proof(prev.random_value().as_ref());
